@@ -1,13 +1,17 @@
 import argparse
+import csv
+import importlib.metadata
 import json
 import logging
 import os
 import pathlib
 import sys
-import version as ver_info
 
+import version as ver_info
 from kodi_interface import KodiObj
 
+__version__ = importlib.metadata.version("kodi-cli")
+
 LOGGER = logging.getLogger(__name__)
 DFLT_LOG_FORMAT = "[%(levelname)-5s] %(message)s"
 DFLT_LOG_LEVEL = logging.ERROR
@@ -50,21 +54,30 @@ def make_dict_from_string(token: str) -> dict:
     """Translate dict formatted string to a dict obj"""
     text = token[1:-1]
     entry_list = text.split(",")
-    whole_list = []
+    result_dict = {}
+    LOGGER.debug(f'make_dict_from_string({token})')
     for entry in entry_list:
-        key_val = entry.split("=")
-        if is_integer(key_val[1]):
-            key_val[1]=int(key_val[1])
-        whole_list.extend([key_val[0], key_val[1]])
-    it = iter(whole_list)
-    result_dict = dict(zip(it, it))
+        key_val = entry.split(":")
+        LOGGER.debug(f'  key_val: {entry}')
+        key = key_val[0].strip()
+        value = key_val[1].strip()
+        if is_integer(value):
+            value=int(value)
+        elif is_boolean(value):
+            value=bool(value)
+        result_dict[key] = value
+
+    LOGGER.debug(f'make_dict_from_string() returns: {result_dict}')
     return result_dict
 
 def build_kwargs_from_args(args: list) -> dict:
     kwargs = {}
+    LOGGER.debug(f"build_kwargs_from_args('{args}')")
     for parm_block in args:
         # param_key=param_value OR param_key=[a,list,of,stuff]
         tokens = parm_block.split("=", 1)
+        LOGGER.debug(f' parm_block: {parm_block}')
+        LOGGER.debug(f'      tokens: {tokens}')
         if len(tokens) == 1:
             kwargs[tokens[0]] = ""
         else:
@@ -79,18 +92,24 @@ def build_kwargs_from_args(args: list) -> dict:
             else:
                 kwargs[tokens[0]] = tokens[1]
     
+    LOGGER.debug(f'build_kwargs_from_args() returns: {kwargs}')
     return kwargs
 
-def parse_input(args: list) -> (str, str, dict):
+def parse_input(args: list) -> (str, str, str, dict):
     """Parse program CLI command parameters, return Namespace, Method, Parms as a tuple"""
     cmd = None
     sub_cmd = None
     parm_kwargs = {}
     namespace = None
     method = None
+    reference = None
     if len(args) > 0:
         namespace = args[0]
-        if "." in namespace:
+        if args[0].count('.') > 1:
+            reference = args[0]
+            print(f'Looks like a reference: {reference}')
+            # method = 'help'
+        elif "." in namespace:
             # namespace.method
             tokens = namespace.split(".")
             namespace = tokens[0]
@@ -101,9 +120,10 @@ def parse_input(args: list) -> (str, str, dict):
     LOGGER.debug('Parsed Command Input:')
     LOGGER.debug(f'  Namespace : {namespace}')
     LOGGER.debug(f'  Method    : {method}')
+    LOGGER.debug(f'  Reference : {reference}')
     LOGGER.debug(f'  kwargs    : {parm_kwargs}')
 
-    return namespace, method, parm_kwargs
+    return reference, namespace, method, parm_kwargs
 
 
 # === Config file routines ========================================================================
@@ -149,7 +169,8 @@ def get_configfile_defaults(cmdline_args: dict = None) -> dict:
                         "port": 8080,
                         "user": "kodiuser",
                         "password": "kodipassword",
-                        "format_output": False, 
+                        "format_output": False,
+                        "json_rpc_loc": "./json-defs",
                         "log_format": f"{DFLT_LOG_FORMAT}",
                         "log_level": DFLT_LOG_LEVEL
                    }
@@ -166,6 +187,8 @@ def get_configfile_defaults(cmdline_args: dict = None) -> dict:
 # === Intro help page ================================================================================
 def display_script_help(usage: str):
     """Display script help dialog to explain how program works"""
+    print()
+    print(__version__)
     print(usage)
     print('Commands are based on Kodi namespaces and methods for each namespace.  When executing a command')
     print('you supply the namespace, the method and any parameters (if required).\n')
@@ -230,9 +253,11 @@ def main() -> int:
     parser.add_argument("-f","--format_output", action="store_true", default=default['format_output'],help="Format json output")
     parser.add_argument("-v","--verbose", action='count', help="Verbose output, -v = INFO, -vv = DEBUG")
     parser.add_argument("-i","--info", action='store_true', help='display program info and quit')
-    parser.add_argument("command", type=str, nargs='*', help="RPC command  namespace.method (help namespace to list)")
+    parser.add_argument("command", type=str, nargs='*', help="RPC command  namespace.method (help namespace to list)",metavar='str')
     args = parser.parse_args()
-  
+    
+    # print(f'** args: {args.command}')
+
     if args.create_config:
         create_config(args)
         return 0
@@ -262,13 +287,15 @@ def main() -> int:
         display_script_help(parser.format_usage())
         return -1  # missing arguments
 
-    kodi = KodiObj(args_dict['host'], args_dict['port'], args_dict['user'], args_dict['password'])
+    kodi = KodiObj(args_dict['host'], args_dict['port'], args_dict['user'], args_dict['password'], args_dict['json_rpc_loc'])
     if loglvl < logging.ERROR:
         dump_args(args_dict)
 
     # Process command-line input
-    namespace, method, param_dict = parse_input(args.command)
-    if namespace == "help":
+    reference, namespace, method, param_dict = parse_input(args.command)
+    if reference:
+        kodi.help(reference)
+    elif namespace == "help":
         kodi.help()
     elif 'help' in param_dict.keys():
         kodi.help(f'{namespace}.{method}')
